==> cheddar-osate2_1.0.0.201812212355.jar: src/cheddar/osate2_plugin/Cheddar_Launch.java <==
package cheddar.osate2_plugin;

import org.eclipse.core.runtime.IProgressMonitor;
import org.osate.aadl2.Element;
import org.osate.aadl2.NamedElement;
import org.osate.aadl2.instance.ComponentInstance;
import org.osate.aadl2.instance.SystemInstance;
import org.osate.ui.dialogs.Dialog;

import cheddar.aadl.ToCheddarModel;
import cheddar.core.XML_Pretty_Printer;

// import  org.osate.internal.workspace;

public class Cheddar_Launch extends Abstract_Plugin {

	@Override
	public String getMarkerType() {
		return "cheddar.osate2_plugin.Cheddar_Launch";
	}

	@Override
	protected String getActionName() {
		return "Run Cheddar V3.x";
	}

	@Override
	public boolean initializeAction(NamedElement obj) {
		setCSVLog("Run Cheddar V3.x", obj);
		return true;
	}


	@Override
	public final void doAaxlAction(final IProgressMonitor monitor, final Element obj) {

		if (!(obj instanceof ComponentInstance)) {
			Dialog.showError("Error", "The selected file is not at the right format");
			monitor.done();
			return;
		}

		SystemInstance si = ((ComponentInstance) obj).getSystemInstance();

		// Produce Cheddar model
		String response;
		response = new ToCheddarModel().parse(si);
		response = XML_Pretty_Printer.Pretty_Print(response);

		// Save Cheddar model in output file and run Cheddar
		String file_info = WriteCheddarXML(response, si.getName());
		String msg = "Cheddar XML V3 model generated in the file :  " + file_info;
		Debug.Put(msg);
		Dialog.showInfo("Instanciate Cheddar model and run Cheddar V3.x, Cheddar model location:", msg);
		Launch l = new Launch();
		l.executeCommand(Config.Cheddar_Command + " " + file_info, Config.Cheddar_Environment,
				Config.Cheddar_Working_Folder);
	}




}

==> cheddar-osate2_1.0.0.201901081024.jar: src/cheddar/osate2_plugin/Cheddar_Launch.java <==
package cheddar.osate2_plugin;

import org.eclipse.core.runtime.IProgressMonitor;
import org.osate.aadl2.Element;
import org.osate.aadl2.NamedElement;
import org.osate.aadl2.instance.ComponentInstance;
import org.osate.aadl2.instance.SystemInstance;
import org.osate.ui.dialogs.Dialog;

import cheddar.aadl.To_System;
import cheddar.core.XML_Pretty_Printer;


public class Cheddar_Launch extends Abstract_Plugin {

	@Override
	public String getMarkerType() {
		return "cheddar.osate2_plugin.Cheddar_Launch";
	}

	@Override
	protected String getActionName() {
		return "Run Cheddar V3.x";
	}

	@Override
	public boolean initializeAction(NamedElement obj) {
		setCSVLog("Run Cheddar V3.x", obj);
		return true;
	}


	@Override
	public final void doAaxlAction(final IProgressMonitor monitor, final Element obj) {

		if (!(obj instanceof ComponentInstance)) {
			Dialog.showError("Error", "The selected file is not at the right format");
			monitor.done();
			return;
		}

		SystemInstance si = ((ComponentInstance) obj).getSystemInstance();

		// Produce Cheddar model
		String response;
		response = new To_System().parse(si);
		response = XML_Pretty_Printer.Pretty_Print(response);

		// Save Cheddar model in output file and run Cheddar
		String file_info = WriteCheddarXML(response, si.getName());
		String msg = "Cheddar XML V3 model generated in the file :  " + file_info;
		Debug.Put(msg);
		Dialog.showInfo("Instanciate Cheddar model and run Cheddar V3.x, Cheddar model location:", msg);
		Launch l = new Launch();
		l.executeCommand(Config.Cheddar_Command + " " + file_info, Config.Cheddar_Environment,
				Config.Cheddar_Working_Folder);
	}




}
